@@ -854,8 +854,13 @@ def get_mon_api_config(config):
     mon_api_config = {'is_enabled': False,
                       'url': '',
                       'project_name': '',
+                      'project_id': '',
+                      'project_domain_name': '',
+                      'project_domain_id': '',
+                      'ca_file': '',
+                      'insecure': '',
                       'username': '',
-                      'password': False,
+                      'password': '',
                       'use_keystone': True,
                       'keystone_url': '',
                       'dimensions': None,
@@ -873,6 +878,11 @@ def get_mon_api_config(config):
     if config.has_section("Api"):
         options = {"url": config.get,
                    "project_name": config.get,
+                   "project_id": config.get,
+                   "project_domain_name": config.get,
+                   "project_domain_id": config.get,
+                   "ca_file": config.get,
+                   "insecure": config.get,
                    "username": config.get,
                    "password": config.get,
                    "use_keystone": config.getboolean,
