@@ -9,7 +9,7 @@ class Cinder(monsetup.detection.ServicePlugin):
         service_params = {
             'template_dir': template_dir,
             'overwrite': overwrite,
-            'service_name': 'cinder',
+            'service_name': 'block-storage',
             'process_names': ['cinder-volume', 'cinder-scheduler',
                               'cinder-api'],
             'service_api_url': 'http://localhost:8776/v2.0',
